# coding: utf-8

"""
    Nomad Envoy

    This is the API descriptor for the Nomad Envoy API, responsible for order creation and product lists.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_envoy_cli
from nomad_envoy_cli.api.customs_api import CustomsApi  # noqa: E501
from nomad_envoy_cli.rest import ApiException


class TestCustomsApi(unittest.TestCase):
    """CustomsApi unit test stubs"""

    def setUp(self):
        self.api = nomad_envoy_cli.api.customs_api.CustomsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_customs_order(self):
        """Test case for post_customs_order

        postCustomsOrder  # noqa: E501
        """
        pass

    def test_post_customs_payment(self):
        """Test case for post_customs_payment

        postCustomsPayment  # noqa: E501
        """
        pass

    def test_post_customs_product(self):
        """Test case for post_customs_product

        postCustomsProduct  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
