# coding: utf-8

"""
    Nomad Envoy

    This is the API descriptor for the Nomad Envoy API, responsible for order creation and product lists.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: paul@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import nomad_envoy_cli
from nomad_envoy_cli.api.order_api import OrderApi  # noqa: E501
from nomad_envoy_cli.rest import ApiException


class TestOrderApi(unittest.TestCase):
    """OrderApi unit test stubs"""

    def setUp(self):
        self.api = nomad_envoy_cli.api.order_api.OrderApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_order(self):
        """Test case for add_order

        addOrder  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        cancelOrder  # noqa: E501
        """
        pass

    def test_get_order_by_field(self):
        """Test case for get_order_by_field

        getOrderByField  # noqa: E501
        """
        pass

    def test_update_order(self):
        """Test case for update_order

        updateOrder  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
